@@ -17,12 +17,19 @@ import os
 import cStringIO
 import re
 import datetime
+from dateutil import parser
 
 class ftpretty(object):
+    """ A wrapper for FTP connections """
     conn = None
+    tmp_output = None
 
-    def __init__(self, host, user, password, secure=False, passive=True, **kwargs): 
-        if secure:
+    def __init__(self, host, user, password, 
+        secure=False, passive=True, ftp_conn=None, **kwargs):
+
+        if ftp_conn:
+            self.conn = ftp_conn
+        elif secure:
             self.conn = FTP_TLS(host=host, user=user, passwd=password, **kwargs)
             self.conn.prot_p()
         else:
@@ -38,7 +45,6 @@ class ftpretty(object):
             return method(*args, **kwargs)
         return wrapper
 
-
     def get(self, remote, local=None):
         """ Gets the file from FTP server
 
@@ -67,7 +73,6 @@ class ftpretty(object):
 
         return None
 
-
     def put(self, local, remote, contents=None):
         """ Puts a local file (or contents) on to the FTP server 
 
@@ -77,7 +82,8 @@ class ftpretty(object):
                 None: contents are pushed
         """       
         remote_dir = os.path.dirname(remote)
-        remote_file = os.path.basename(local) if remote.endswith('/') else os.path.basename(remote)
+        remote_file = os.path.basename(local)\
+            if remote.endswith('/') else os.path.basename(remote)
 
         if contents:
             # local is ignored if contents is set
@@ -93,98 +99,102 @@ class ftpretty(object):
         try:
             self.conn.storbinary('STOR %s' % remote_file, local_file)
             size = self.conn.size(remote_file)
-        except Exception as e:
-            print e
+        except Exception as exc:
+            print exc
         finally:
             local_file.close()
             self.conn.cwd(current)
         return size
 
-
     def list(self, remote='.', extra=False):
         """ Return directory list """
         if not extra:
             return self.conn.nlst(remote)
         self.tmp_output = []
         self.conn.dir(remote, self._collector)
-        return self.split_file_info(self.tmp_output)
-
-
-    def _collector(self, line):
-        self.tmp_output.append(line)
-
+        return split_file_info(self.tmp_output)
 
     def descend(self, remote, force=False):
         """ Descend, possibly creating directories as needed """
         remote_dirs = remote.split('/')
-        for dir in remote_dirs:
+        for directory in remote_dirs:
             try:
-                self.conn.cwd(dir)
-            except:
+                self.conn.cwd(directory)
+            except Exception as exc:
                 if force:
-                    self.conn.mkd(dir)
-                    self.conn.cwd(dir)
+                    self.conn.mkd(directory)
+                    self.conn.cwd(directory)
         return self.conn.pwd()
 
-
     def delete(self, remote):
+        """ Delete a file from server """
         try:
             self.conn.delete(remote)
-        except:
+        except Exception as exc:
             return False
         else:
             return True        
 
-
     def cd(self, remote):
+        """ Change working directory on server """
         try:
             self.conn.cwd(remote)
-        except:
+        except Exception as exc:
             return False
         else:
             return self.pwd()
 
-
     def pwd(self):
+        """ Return the current working directory """
         return self.conn.pwd()
 
-
     def close(self):
+        """ End the session """
         try:
             self.conn.quit()
-        except:
+        except Exception as exc:
             self.conn.close()
 
+    def _collector(self, line):
+        """ Helper for collecting output from dir() """
+        self.tmp_output.append(line)
 
-    def split_file_info(self, fileinfo):
-        """ Parse sane directory output usually ls -l
-            Adapted from https://gist.github.com/tobiasoberrauch/2942716 
-        """
-        current_year = datetime.datetime.now().strftime('%Y')
-        files = []        
-        for line in fileinfo:
-            parts = re.split(
-                '^([\\-dbclps])' +                # Directory flag [1]
-                '([\\-rwxs]{9})\\s+' +            # Permissions [2]
-                '(\\d+)\\s+' +                    # Number of items [3]
-                '(\\w+)\\s+' +                    # File owner [4]
-                '(\\w+)\\s+' +                    # File group [5]
-                '(\\d+)\\s+' +                    # File size in bytes [6]
-                '(\\w{3}\\s+\\d{1,2})\\s+' +       # 3-char month and 1/2-char day of the month [7]
-                '(\\d{1,2}:\\d{1,2}|\\d{4})\\s+' + # Time or year (need to check conditions) [+= 7]
-                '(.+)$'                       # File/directory name [8]
-                , line)
-            files.append({
-                'directory': parts[1],
-                'perms': parts[2],
-                'items': parts[3],
-                'owner': parts[4],
-                'group': parts[5],
-                'size': parts[6],
-                'date': parts[7],
-                'time': parts[8] if ':' in parts[8] else '00:00',
-                'year': parts[8] if ':' not in parts[8] else current_year,
-                'name': parts[9]
-                }) 
-        return files
+def split_file_info(fileinfo):
+    """ Parse sane directory output usually ls -l
+        Adapted from https://gist.github.com/tobiasoberrauch/2942716 
+    """
+    current_year = datetime.datetime.now().strftime('%Y')
+    files = []        
+    for line in fileinfo:
+        parts = re.split(
+            '^([\\-dbclps])' +                # Directory flag [1]
+            '([\\-rwxs]{9})\\s+' +            # Permissions [2]
+            '(\\d+)\\s+' +                    # Number of items [3]
+            '(\\w+)\\s+' +                    # File owner [4]
+            '(\\w+)\\s+' +                    # File group [5]
+            '(\\d+)\\s+' +                    # File size in bytes [6]
+            '(\\w{3}\\s+\\d{1,2})\\s+' +       # 3-char month and 1/2-char day of the month [7]
+            '(\\d{1,2}:\\d{1,2}|\\d{4})\\s+' + # Time or year (need to check conditions) [+= 7]
+            '(.+)$'                       # File/directory name [8]
+            , line)
+
+        date = parts[7]
+        time = parts[8] if ':' in parts[8] else '00:00'
+        year = parts[8] if ':' not in parts[8] else current_year
+        dt_obj = parser.parse("%s %s %s" % (date, year, time) )
+
+        files.append({
+            'directory': parts[1],
+            'perms': parts[2],
+            'items': parts[3],
+            'owner': parts[4],
+            'group': parts[5],
+            'size': int(parts[6]),
+            'date': date,
+            'time': time,
+            'year': year,
+            'name': parts[9],
+            'datetime': dt_obj
+            }) 
+    return files
 
